@@ -38,9 +38,12 @@ EXPORTABLE_RELATIONS = ['Roles', 'NotificationTemplates', 'WorkflowJobTemplateNo
 DEPENDENT_EXPORT = [
     ('JobTemplate', 'Label'),
     ('JobTemplate', 'SurveySpec'),
+    ('JobTemplate', 'Schedule'),
     ('WorkflowJobTemplate', 'Label'),
     ('WorkflowJobTemplate', 'SurveySpec'),
+    ('WorkflowJobTemplate', 'Schedule'),
     ('WorkflowJobTemplate', 'WorkflowJobTemplateNode'),
+    ('InventorySource', 'Schedule'),
     ('Inventory', 'Group'),
     ('Inventory', 'Host'),
     ('Inventory', 'Label'),
@@ -63,7 +66,6 @@ DEPENDENT_NONEXPORT = [
 
 
 class Api(base.Base):
-
     pass
 
 
@@ -71,7 +73,6 @@ page.register_page(resources.api, Api)
 
 
 class ApiV2(base.Base):
-
     # Export methods
 
     def _export(self, _page, post_fields):
